Module ser
twine_
data
0.1.0
Module ser
Module Items
Structs
Type Aliases
In crate twine_
data
twine_data
Module
ser
Encoder.
The encoder is used to write a complex DAG, in the twine format, into a byte stream.
Structs

Encoder
Type Aliases

Result