pub enum Immediate<'a> {
Null,
Bool(bool),
Int64(i64),
Float(f64),
String(&'a str),
Bytes(&'a [u8]),
Variant0(VariantIdx),
Ref(Offset),
Pointer(Offset),
}Expand description
Immediate value, without nesting.
An immediate value is one that can be skipped over efficiently. Only immediate values can be stored in arrays and maps; more complex values have to be stored indirectly via a reference.
Variants
Null
CBOR/JSON null.
Bool(bool)
Int64(i64)
Float(f64)
String(&'a str)
Text, in UTF8
Bytes(&'a [u8])
Binary blob.
Variant0(VariantIdx)
A variant with 0 arguments.
Ref(Offset)
An explicit reference to a full value (which comes at an earlier offset).
Pointer(Offset)
An automatically followed reference to a full value (which comes at an earlier offset).