Full, nested values, with individual allocations.
Such values are useful for various tools that need a global view of the data, or for manipulating twine data as if it were JSON.
Enums
- Value
- A value, potentially containing other values. All the sub-values live in the same allocator.
Functions
- read_
value - Read a value from a decoder, starting at given offset.
- read_
value_ from_ entrypoint - Find the entrypoint and read a value from it.
- write_
value - Write a value, return an offset to it.